<h1> excelbird &nbsp;&nbsp;&nbsp; <a href="https://pypi.org/project/excelbird/" alt="Version"> <img src="https://img.shields.io/pypi/v/excelbird.svg" /></a> &nbsp;&nbsp;&nbsp; <a href="https://github.com/ryayoung/excelbird/actions"> <img src="https://github.com/ryayoung/excelbird/actions/workflows/tests.yaml/badge.svg"/> </a> </h1>

### <a href="https://excelbird.readthedocs.io/en/latest/"><img src="https://github.com/ryayoung/icons/blob/main/svg/code.file.blue.svg" height="22"/> &nbsp; Documentation</a> &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; <a href="https://pypi.org/project/excelbird/"><img src="https://github.com/ryayoung/icons/blob/main/svg/folder.blue.svg" height="22"/> &nbsp; PyPI</a>

```text
pip install excelbird
```

> **A front-end framework for Excel that can do magical things.**

Layout and styling is as easy as building an HTML page. You don't have to tell cells where to go.

Excelbird objects create and store cell references on their own, and can be used in python arithmetic expressions which will be lazily evaluated to render your expression as an excel formula with real cell references.
